@@ -23,13 +23,24 @@ class AuthenticationError(Exception):
     pass
 
 
+class NoTokenError(Exception):
+    pass
+
+
 def get_api_endpoint():
     domain = os.environ.get('PYTHONANYWHERE_DOMAIN', 'pythonanywhere.com')
     return 'https://www.{domain}/api/v0/user/{{username}}/webapps/'.format(domain=domain)
 
 
 def call_api(url, method, **kwargs):
-    token = os.environ['API_TOKEN']
+    token = os.environ.get('API_TOKEN')
+    if token is None:
+        raise NoTokenError(
+            "Oops, you don't seem to have an API token.  "
+            "Please go to the 'Account' page on PythonAnywhere, then to the 'API Token' "
+            "tab.  Click the 'Create a new API token' button to create the token, then "
+            "start a new console and try running this script again."
+        )
     insecure = os.environ.get('PYTHONANYWHERE_INSECURE_API') == 'true'
     response = requests.request(
         method=method,
