@@ -1,4 +1,4 @@
-#!/usr/bin/env python3.6
+#!/usr/bin/env python3.5
 import sys
 import textwrap
 
@@ -20,14 +20,14 @@ def speech_bubble_lines(speech):
     lines, width = rewrap(speech)
     if len(lines) <= 1:
         text = ''.join(lines)
-        yield f'< {text} >'
+        yield '< {text} >'.format(text=text)
 
     else:
         yield '  ' + '_' * width
-        yield f'/ {lines[0]} \\'
-        for line in lines[1:-1]:
-            yield f'| {line} |'
-        yield fr'\ {lines[-1]} /'
+        yield '/ ' + (' ' * width) + ' \\'
+        for line in lines:
+            yield '| {} |'.format(line)
+        yield '\\ ' + (' ' * width) + ' /'
         yield '  ' + '-' * width
 
 
